|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r56096 - in trunk/boost/spirit/home/lex/lexer: . lexertl
From: hartmut.kaiser_at_[hidden]
Date: 2009-09-07 18:24:34
Author: hkaiser
Date: 2009-09-07 18:24:33 EDT (Mon, 07 Sep 2009)
New Revision: 56096
URL: http://svn.boost.org/trac/boost/changeset/56096
Log:
Spirit: disambiguated lex::omit
Text files modified:
trunk/boost/spirit/home/lex/lexer/lexertl/token.hpp | 18 +++++++++---------
trunk/boost/spirit/home/lex/lexer/token_def.hpp | 2 +-
2 files changed, 10 insertions(+), 10 deletions(-)
Modified: trunk/boost/spirit/home/lex/lexer/lexertl/token.hpp
==============================================================================
--- trunk/boost/spirit/home/lex/lexer/token_def.hpp (original)
+++ trunk/boost/spirit/home/lex/lexer/token_def.hpp 2009-09-07 18:24:33 EDT (Mon, 07 Sep 2009)
@@ -102,7 +102,7 @@
typedef typename mpl::if_<
traits::is_not_unused<Attribute>
, typename mpl::if_<
- is_same<Attribute, omit>, unused_type, Attribute
+ is_same<Attribute, lex::omit>, unused_type, Attribute
>::type
, iterator_range<iterator_type>
>::type type;
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- trunk/boost/spirit/home/lex/lexer/lexertl/token.hpp (original)
+++ trunk/boost/spirit/home/lex/lexer/lexertl/token.hpp 2009-09-07 18:24:33 EDT (Mon, 07 Sep 2009)
@@ -112,7 +112,7 @@
// doesn't support working with lexer states.
///////////////////////////////////////////////////////////////////////////
template <typename Iterator>
- struct token<Iterator, omit, mpl::false_>
+ struct token<Iterator, lex::omit, mpl::false_>
{
typedef Iterator iterator_type;
typedef mpl::false_ has_state;
@@ -188,11 +188,11 @@
// supports working with lexer states.
///////////////////////////////////////////////////////////////////////////
template <typename Iterator>
- struct token<Iterator, omit, mpl::true_>
- : token<Iterator, omit, mpl::false_>
+ struct token<Iterator, lex::omit, mpl::true_>
+ : token<Iterator, lex::omit, mpl::false_>
{
private:
- typedef token<Iterator, omit, mpl::false_> base_type;
+ typedef token<Iterator, lex::omit, mpl::false_> base_type;
public:
typedef typename base_type::id_type id_type;
@@ -256,7 +256,7 @@
// The type of the data item stored with a token instance is defined
// by the template parameter 'AttributeTypes' and may be:
//
// omit: no data item is stored with the token
// instance (this is handled by the
// specializations of the token class
// below)
@@ -283,14 +283,14 @@
}
template <typename Iterator, typename AttributeTypes, typename HasState>
- struct token : token<Iterator, omit, HasState>
+ struct token : token<Iterator, lex::omit, HasState>
{
private: // precondition assertions
#if !BOOST_WORKAROUND(BOOST_MSVC, <= 1300)
BOOST_STATIC_ASSERT((mpl::is_sequence<AttributeTypes>::value ||
- is_same<AttributeTypes, omit>::value));
+ is_same<AttributeTypes, lex::omit>::value));
#endif
- typedef token<Iterator, omit, HasState> base_type;
+ typedef token<Iterator, lex::omit, HasState> base_type;
protected:
// If no additional token value types are given, the the token will
@@ -456,7 +456,7 @@
// constructed values.
template <typename Attribute, typename Iterator, typename HasState>
inline void
- construct(Attribute& attr, token<Iterator, omit, HasState>& t) {}
+ construct(Attribute& attr, token<Iterator, lex::omit, HasState>& t) {}
// This is called from the parse function of lexer_def_
template <typename Iterator, typename AttributeTypes, typename HasState>
Modified: trunk/boost/spirit/home/lex/lexer/token_def.hpp
@@ -256,7 +256,7 @@
// by the template parameter 'AttributeTypes' and may be:
//
- // omit: no data item is stored with the token
+ // lex::omit: no data item is stored with the token
// instance (this is handled by the
// specializations of the token class
==============================================================================